//
//  Note+Helper.swift
//  SlipboxProject
//
//  Created by Karin Prater on 19.11.22.
//

import Foundation
import CoreData

extension Note {
    
    var title: String {
        get { self.title_ ?? "" }
        set { self.title_ = newValue  }
    }
    
    var status: Status {
        get {
            if let rawStatus = status_,
              let status = Status(rawValue: rawStatus){
                return status
            } else {
                return Status.draft
            }
        }
        set {
            status_ = newValue.rawValue
        }
    }
    
    var formattedBodyText: NSAttributedString {
        get {
            formattedBodyText_?.toAttributedString() ?? NSAttributedString(string: "")
        }
        set {
            formattedBodyText_ =  newValue.toData()
            bodyText_ = newValue.string.lowercased()
        }
    }
    
    var bodyText: String {
        get { bodyText_ ?? "" }
    }
    
    convenience init(title: String, context: NSManagedObjectContext) {
        self.init(context: context)
        self.title = title
    }
 
    public override func awakeFromInsert() {
        self.creationDate = Date()
    }
    
   static func fetch(_ predicate: NSPredicate = .all) -> NSFetchRequest<Note> {
        let request = NSFetchRequest<Note>(entityName: "Note")
        request.sortDescriptors = [NSSortDescriptor(keyPath: \Note.creationDate, ascending: true)]
        request.predicate = predicate
        
        return request
    }
    
    static func delete(note: Note) {
        guard let context = note.managedObjectContext else { return }
        
        context.delete(note)
    }
    
}
